@@ -20,13 +20,21 @@ from six import string_types
 
 import collections
 
+try:
+    collectionsAbc = collections.abc
+except AttributeError:
+    collectionsAbc = collections
+
 from glanceclient import client as glance_client
 from heatclient import client as heat_client
+from heatclient import exc as heat_exc
 from ironicclient import client as ironic_client
 from keystoneauth1.identity import generic as ks_id
 from keystoneauth1 import session as ks_session
 from novaclient import client as nova_client
 from swiftclient.client import Connection
+from swiftclient import exceptions as swiftexceptions
+from tripleo_validations import constants
 
 
 def get_auth_session(auth_variables):
@@ -54,11 +62,15 @@ def get_auth_session(auth_variables):
 
 
 def get_swift_client(auth_variables):
+    password = auth_variables.get('password')
+    if password:
+        return Connection(authurl=auth_variables.get('auth_url'),
+                          user=auth_variables.get('username'),
+                          key=password,
+                          auth_version='3',
+                          tenant_name=auth_variables.get('project_name'))
     return Connection(preauthurl=auth_variables.get('undercloud_swift_url'),
-                      preauthtoken=auth_variables.get('os_auth_token'),
-                      retries=10,
-                      starting_backoff=3,
-                      max_backoff=120)
+                      preauthtoken=auth_variables.get('os_auth_token'))
 
 
 def get_nova_client(auth_variables):
@@ -74,16 +86,28 @@ def get_heat_client(auth_variables):
 
 
 def get_ironic_client(auth_variables):
-    session = get_auth_session(auth_variables)
-    ironic_url = session.get_endpoint(service_type='baremetal',
-                                      interface='public')
     return ironic_client.get_client(
         1,
-        ironic_url=ironic_url,
-        os_auth_token=auth_variables.get('os_auth_token')
+        session=get_auth_session(auth_variables)
     )
 
 
+def list_plan_and_stack(hclient, swiftclient):
+    try:
+        stacks = [s.stack_name for s in hclient.stacks.list()]
+    except heat_exc.HTTPNotFound:
+        return None
+    try:
+        plan_list = []
+        for ac in swiftclient.get_account()[1]:
+            container = swiftclient.get_container(ac['name'])[0]
+            if constants.TRIPLEO_META_USAGE_KEY in container.keys():
+                plan_list.append(ac['name'])
+    except swiftexceptions.ClientException:
+        return None
+    return list(set(stacks).union(plan_list))
+
+
 def filtered(obj):
     """Only return properties of obj whose value can be properly serialized."""
     return {k: v for k, v in obj.__dict__.items()
@@ -101,12 +125,12 @@ def get_nested(data, name, path):
                 raise ValueError("The '{}' property of '{}' must be a {}."
                                  "".format(key, name, instance_name))
             return data[key]
-        for item in data.values():
-            if isinstance(item, collections.Mapping):
-                return deep_find_key(key_data, item, name)
+        for k, v in sorted(data.items()):
+            if isinstance(v, collectionsAbc.Mapping):
+                return deep_find_key(key_data, v, name)
         return None
 
-    if not isinstance(data, collections.Mapping):
+    if not isinstance(data, collectionsAbc.Mapping):
         raise ValueError(
             "'{}' is not a valid resource.".format(name))
 
